pub struct DenseIdMapWithReuse<K, V> { /* private fields */ }Expand description
Like a DenseIdMap, but supports freeing (and reusing) slots.
Implementations
Sourceimpl<K: NumericId, V> DenseIdMapWithReuse<K, V>
impl<K: NumericId, V> DenseIdMapWithReuse<K, V>
Sourcepub fn reserve_slot(&mut self) -> K
pub fn reserve_slot(&mut self) -> K
Reserve a slot in the map for use later with DenseIdMapWithReuse::insert.
Sourcepub fn insert(&mut self, key: K, value: V)
pub fn insert(&mut self, key: K, value: V)
Insert the given mapping into the table. You probably
want to use DenseIdMapWithReuse::push instead, unless you need to use
the key to build the value, in which case you can
use DenseIdMapWithReuse::reserve_slot to get the key for this method.