DenseIdMapWithReuse

Struct DenseIdMapWithReuse 

pub struct DenseIdMapWithReuse<K, V> { /* private fields */ }
Like a DenseIdMap, but supports freeing (and reusing) slots.

Implementations

Source

impl<K: NumericId, V> DenseIdMapWithReuse<K, V>

pub fn reserve_slot(&mut self) -> K

Reserve a slot in the map for use later with DenseIdMapWithReuse::insert.

pub fn insert(&mut self, key: K, value: V)

Insert the given mapping into the table. You probably want to use DenseIdMapWithReuse::push instead, unless you need to use the key to build the value, in which case you can use DenseIdMapWithReuse::reserve_slot to get the key for this method.

pub fn push(&mut self, value: V) -> K

Add the given value to the table.

pub fn take(&mut self, id: K) -> Option<V>

Remove the given key from the table, if it is present.